@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# Copyright (c) 2016-2023, Babak Farrokhi
+# Copyright (c) 2016-2024, Babak Farrokhi
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -63,8 +63,8 @@ usage: %s [-ehmvCTXH] [-f server-list] [-j output.json] [-c count] [-t type] [-p
   -H  --doh         Use HTTPS as transport protols (DoH)
   -p  --port        DNS server port number (default: 53 for TCP/UDP and 853 for TLS)
   -S  --srcip       Query source IP address
-  -e  --edns        Disable EDNS0 (default: Enabled)
-  -D  --dnssec      Enable 'DNSSEC desired' flag in requests.
+  -e  --edns        Enable EDNS0
+  -D  --dnssec      Enable 'DNSSEC desired' (DO flag) in requests
   -C  --color       Print colorful output
   -v  --verbose     Print actual dns response
 """ % (__progname__, __version__, __progname__))
@@ -92,7 +92,7 @@ def main():
     inputfilename = None
     fromfile = False
     json_output = False
-    use_edns = True
+    use_edns = False
     want_dnssec = False
     force_miss = False
     verbose = False
@@ -100,9 +100,9 @@ def main():
     qname = 'wikipedia.org'
 
     try:
-        opts, args = getopt.getopt(sys.argv[1:], "hf:c:t:w:S:TevCmXHDj:",
+        opts, args = getopt.getopt(sys.argv[1:], "hf:c:t:w:S:TevCmXHDj:p:",
                                    ["help", "file=", "count=", "type=", "wait=", "json=", "tcp", "edns", "verbose",
-                                    "color", "cache-miss", "srcip=", "tls", "doh", "dnssec"])
+                                    "color", "cache-miss", "srcip=", "tls", "doh", "dnssec", "port="])
     except getopt.GetoptError as err:
         print(err)
         usage()
@@ -134,19 +134,20 @@ def main():
             json_output = True
             json_filename = a
         elif o in ("-e", "--edns"):
-            use_edns = False
+            use_edns = True
         elif o in ("-D", "--dnssec"):
             want_dnssec = True
+            use_edns = True  # implied
         elif o in ("-C", "--color"):
             color_mode = True
         elif o in ("-v", "--verbose"):
             verbose = True
         elif o in ("-X", "--tls"):
             proto = PROTO_TLS
-            dst_port = 853  # default for DoT, unless overriden using -p
+            dst_port = 853  # default for DoT, unless overridden using -p
         elif o in ("-H", "--doh"):
             proto = PROTO_HTTPS
-            dst_port = 443  # default for DoH, unless overriden using -p
+            dst_port = 443  # default for DoH, unless overridden using -p
         elif o in ("-p", "--port"):
             dst_port = int(a)
 
@@ -154,6 +155,11 @@ def main():
             print("Invalid option: %s" % o)
             usage()
 
+    # validate RR type
+    if not util.dns.valid_rdatatype(rdatatype):
+        print('Error: Invalid record type "%s" ' % rdatatype)
+        sys.exit(1)
+
     color = Colors(color_mode)
 
     try:
@@ -173,7 +179,7 @@ def main():
             f = dns.resolver.get_default_resolver().nameservers
 
         if len(f) == 0:
-            print("No nameserver specified")
+            print("Error: No nameserver specified")
 
         f = [name.strip() for name in f]  # remove annoying blanks
         f = [x for x in f if not x.startswith('#') and len(x)]  # remove comments and empty entries
